@@ -20,7 +20,7 @@ autoflush STDOUT 1;
 
 # ABSTRACT: C source analysis
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 # PODNAME: c2ast.pl
 
@@ -323,27 +323,24 @@ where options can be:
                      This has been observed on Darwin for instance, where one have to say:
                      --cpp gcc --cpp -E
 
---cppfile <filename> The output of the preprocessor will contain a lot of lines like '#line "filename"', where
-                     "filename" is guaranteed to be the constant for a given physical location in the filesystem.
-                     The first occurence is always a marker of the source that c2ast sent to the preprocessor.
-                     c2ast will catch it so that the --lexeme tracing phase, or the --check phase, will happen only
-                     on lexemes relevant to the source file given on the command-line, and not polluted by lexemes
-                     coming from any included file.
+--cppfile <filename> The name of the file being preprocessed.  Usually this option is not necessary.  By
+                     default this is the main file being pre-processed, as indicated by the first preprocessor
+                     line directive.  (Preprocessor line directives start are lines starting with '#line'.)
+                     For the --lexeme tracing phase or the --check phase, c2ast includes only the information
+                     that is relevant to the lexemes contained in the "cppfile".
 
-                     Nevertheless, the source given on the command-line /could/ be the result of another preprocessing phase.
-                     You can use this option to tell c2ast what is the real filename to consider.
+                     One circumstance where this option is necessary if when the C files are not the source
+                     files, but were generated by another program.  For example, the input file might be named
+                     'generated.c', but the actual source, from which 'generated.c' was generated, might be
+                     in a file named 'source.c'.  If convention is being followed, 'generated.c' will contain
+                     lines of the form, to indicate which portions of the code originally came from 'source.c'.
 
-                     For example, suppose your .c file has the name: my/generated/source.c. And that the real origin is
-                     my/input/source.w, where my/input/source.w has been preprocessed by you to generate
-                     my/generated/source.c.
+                     # line xxx "source.c"
 
-                     Then, it is very likely that my/generated/source.c will contain a line like:
-                     # line xxx "my/input/source.c"
+                     You can tell c2ast.pl to analyze the code originally from "source.c", as indicated by the
+                     preprocessor line directives, with the option
 
-                     You will then say --cppfile "my/input/source.c".
-
-                     Exemple: the file marpa.c in the build phase of libmarpa: this is the result of
-                     a preprocessing on the file marpa.w.
+                       --cppfile "source.c"
 
 --cppdup <filename>  Save the preprocessed output to this filename. Only useful for debugging c2ast.
 
@@ -378,7 +375,7 @@ where options can be:
 
                      Note that tracing Marpa library itself is possible, but only using environment variable MARPA_TRACE /and/ saying --loglevel TRACE.
 
-                     In case of trouble, typical debuggin of c2ast is:
+                     In case of trouble, typical debugging phases c2ast are:
                      --loglevel INFO
                      then:
                      --loglevel DEBUG
@@ -416,7 +413,7 @@ c2ast.pl - C source analysis
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
